@@ -64,7 +64,8 @@ def addSwagger(apiInstance, appInstance):
     )
     swaggerUi._static_folder = f'{globals.currentPath}api{globals.OS_SEPARATOR}resource{globals.OS_SEPARATOR}swaggerui{globals.OS_SEPARATOR}'
     log.debug(addSwagger, f'''Swagger static folder at "{swaggerUi._static_folder}"''')
-    log.debug(addSwagger, f'''Swagger lib at "{__name__}"''')
+    log.debug(addSwagger, f'''Swagger lib name "{__name__}"''')
+    log.debug(addSwagger, f'''Swagger lib folder "{__folder__}"''')
     # swaggerUi._static_folder = f'{OpenApiDocumentationFile.getDocumentationFolderPath(apiInstance)}{globals.OS_SEPARATOR}'
     appInstance.register_blueprint(swaggerUi, url_prefix=documentationUrl)
     OpenApiDocumentationFile.overrideDocumentation(apiInstance)
